mkdir %LIBRARY_BIN%
copy %RECIPE_DIR%\conda_build_wrapper.sh              %LIBRARY_BIN%\
copy %RECIPE_DIR%\create_def.sh                       %LIBRARY_BIN%\
copy %RECIPE_DIR%\run_autotools_clang_conda_build.bat %LIBRARY_BIN%\
